@@ -29,6 +29,7 @@
 #define LANG_COFFEESCRIPT "coffeescript"
 #define LANG_COQ "coq"
 #define LANG_CPP "cpp"
+#define LANG_CRYSTAL "crystal"
 #define LANG_CS_ASPX "cs_aspx"
 #define LANG_CSHARP "csharp"
 #define LANG_CSS "css"
@@ -61,8 +62,10 @@
 #define LANG_JAVA "java"
 #define LANG_JAVASCRIPT "javascript"
 #define LANG_JSP "jsp"
+#define LANG_KOTLIN "kotlin"
 #define LANG_LIMBO "limbo"
 #define LANG_LISP "lisp"
+#define LANG_LIVECODE "livecode"
 #define LANG_LOGTALK "logtalk"
 #define LANG_LUA "lua"
 #define LANG_MAKE "make"
@@ -71,6 +74,7 @@
 #define LANG_METAFONT "metafont"
 #define LANG_METAPOST "metapost"
 #define LANG_METAPOST_WITH_TEX "metapost_with_tex"
+#define LANG_MODELICA "modelica"
 #define LANG_MODULA2 "modula2"
 #define LANG_MODULA3 "modula3"
 #define LANG_MXML "mxml"
@@ -85,6 +89,7 @@
 #define LANG_PERL "perl"
 #define LANG_PHP "php"
 #define LANG_PIKE "pike"
+#define LANG_POSTSCRIPT "postscript"
 #define LANG_PROLOG "prolog"
 #define LANG_PUPPET "puppet"
 #define LANG_PYTHON "python"
@@ -107,6 +112,7 @@
 #define LANG_TCL "tcl"
 #define LANG_TEX "tex"
 #define LANG_TEX_DTX "tex_dtx"
+#define LANG_UNREALSCRIPT "unrealscript"
 #define LANG_TYPESCRIPT "typescript"
 #define LANG_VALA "vala"
 #define LANG_VB_ASPX "vb_aspx"
